#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "Christian Heider Nielsen"
__doc__ = r"""

           Created on 14/01/2020
           """


from .gauss_circles import *
from .segment_ellipse import *



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 8/24/22
           """

__all__ = ["in_ipynb"]

import sys


def in_ipynb(verbose: bool = False) -> bool:
    """

    :return:
    :rtype:
    """
    try:
        from IPython import get_ipython
        import jupyter

        shell = get_ipython().__class__.__name__
        if verbose:
            print(f"found shell: {shell}")
        if shell == "ZMQInteractiveShell":
            return True  # Jupyter notebook or qtconsole
        elif shell == "TerminalInteractiveShell":
            return False  # Terminal running IPython
        else:
            return False  # Other type (?)
    except NameError:
        if verbose:
            print(f"Probably standard Python interpreter")
        return False  # Probably standard Python interpreter
    except ModuleNotFoundError:
        if "ipykernel" in sys.modules:
            if verbose:
                print(f"Found ipykernel in sys.modules")
            return True

        if verbose:
            print(f"Did not find Ipython")
        return False  # Did not find Ipython


if __name__ == "__main__":
    in_ipynb()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "Christian Heider Nielsen"
__doc__ = r"""

           Created on 21/02/2020
           """

from pathlib import Path

with open(Path(__file__).parent / "README.md", "r") as this_init_file:
    __doc__ += this_init_file.read()
# del Path

from .data_type import *
from .device import *
from .info import *
from .seeding import *
from .constants import *
from .loading import *



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 11/30/22
           """

__all__ = ["get_video_sources"]

from pathlib import Path
from typing import Set


def get_video_sources() -> Set[int]:
    """
    video_source_indices

    :return:
    :rtype:
    """
    char_devices = [f for f in Path("/dev").iterdir() if f.is_char_device()]
    return set(
        sorted(
            [int(dev.name[-1]) for dev in char_devices if dev.name.startswith("video")]
        )
    )
